<?php

/**
 * Plugin Name: Buy Again for WooCommerce
 * Description: Your customers can quickly purchase the products which they had purchased earlier in your site.
 * Version: 2.7
 * Author: FantasticPlugins
 * Author URI: https://fantasticplugins.com
 * Text Domain: buy-again-for-woocommerce
 * Domain Path: /languages
 * Woo: 5134099:587b5729b4b3c9533ee01be25419d1f8
 * Tested up to: 5.9.1
 * WC tested up to: 6.2.1
 * WC requires at least: 3.0
 * Copyright: © 2019 FantasticPlugins
 * License: GNU General Public License v3.0
 * License URI: http://www.gnu.org/licenses/gpl-3.0.html
 *
 */
if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly.
}

/* Include once will help to avoid fatal error by load the files when you call init hook */
include_once( ABSPATH . 'wp-admin/includes/plugin.php' );

/**
 * Function to check whether WooCommerce is active or not
 */
function bya_maybe_woocommerce_active() {

	if (is_multisite()) {
		// This Condition is for Multi Site WooCommerce Installation
		if (!is_plugin_active_for_network('woocommerce/woocommerce.php') && ( !is_plugin_active('woocommerce/woocommerce.php') )) {
			if (is_admin()) {
				add_action('init', 'bya_display_warning_message');
			}
			return false;
		}
	} else {
		// This Condition is for Single Site WooCommerce Installation
		if (!is_plugin_active('woocommerce/woocommerce.php')) {
			if (is_admin()) {
				add_action('init', 'bya_display_warning_message');
			}
			return false;
		}
	}
	return true;
}

/**
 * Display Warning message
 */
function bya_display_warning_message() {
	echo "<div class='error'><p> Buy Again for WooCommerce Plugin will not work until WooCommerce Plugin is Activated. Please Activate the WooCommerce Plugin. </p></div>";
}

// retrun if WooCommerce is not active
if (!bya_maybe_woocommerce_active()) {
	return;
}

// Define constant
if (!defined('BYA_PLUGIN_FILE')) {
	define('BYA_PLUGIN_FILE', __FILE__);
}

// Include main class file
if (!class_exists('FP_Buy_Again')) {
	include_once( 'inc/class-buy-again.php' );
}

// return Buy Again class object
if (!function_exists('BYA')) {

	function BYA() {
		return FP_Buy_Again::instance();
	}

}

// initialize the plugin.
BYA();
