<?php

/*
 * Common functions
 */

if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly.
}

include_once( 'bya-layout-functions.php' );
include_once( 'bya-post-functions.php' );
include_once( 'bya-formatting-functions.php' );

if (!function_exists('bya_check_is_array')) {

	/**
	 * Function to check given a variable is array and not empty
	 * 
	 * @return boolean
	 */
	function bya_check_is_array( $array) {

		if (is_array($array) && !empty($array)) {
			return true;
		} else {
			return false;
		}
	}

}

if (!function_exists('bya_get_settings_page_url')) {

	/**
	 * Get Settings page URL
	 *
	 * @return array
	 */
	function bya_get_settings_page_url( $args = array()) {

		$url = add_query_arg(array('page' => 'bya_settings'), admin_url('admin.php'));

		if (bya_check_is_array($args)) {
			$url = add_query_arg($args, $url);
		}

		return $url;
	}

}

if (!function_exists('bya_get_allowed_setting_tabs')) {

	/**
	 * Get setting tabs
	 *
	 * @return array
	 */
	function bya_get_allowed_setting_tabs() {

		return apply_filters('bya_settings_tabs_array', array());
	}

}

if (!function_exists('bya_page_screen_ids')) {

	/**
	 * Get page screen IDs
	 *
	 * @return array
	 */
	function bya_page_screen_ids() {
		return apply_filters('bya_page_screen_ids', array('buy-again_page_bya_settings'));
	}

}

if (!function_exists('bya_get_order_statuses')) {

	/**
	 * Get to order status
	 * 
	 * @return array
	 * */
	function bya_get_order_statuses() {
		$order_statuses = array();
		if (function_exists('wc_get_order_statuses')) {
			$wc_order_statuses = wc_get_order_statuses();
			$orderstatuses = str_replace('wc-', '', array_keys($wc_order_statuses));
			$orderslugs = array_values($wc_order_statuses);
			$order_statuses = array_combine((array) $orderstatuses, (array) $orderslugs);
		}

		return $order_statuses;
	}

}

if (!function_exists('bya_get_categories')) {

	/**
	 * Get categories
	 * 
	 * @return array
	 * */
	function bya_get_categories() {
		$categorylist = array();
		$categoryname = array();
		$categoryid = array();

		$categories = get_terms('product_cat');

		if (is_wp_error($categories) || !bya_check_is_array($categories)) {
			return $categorylist;
		}

		foreach ($categories as $category) {
			$categoryname[] = $category->name;
			$categoryid[] = $category->term_id;
		}

		$categorylist = array_combine((array) $categoryid, (array) $categoryname);

		return $categorylist;
	}

}

if (!function_exists('bya_get_user_roles')) {

	/**
	 * Get User Roles
	 * 
	 * @return array
	 * */
	function bya_get_user_roles() {
		global $wp_roles;
		$user_roles = array();

		if (!isset($wp_roles->roles) || !bya_check_is_array($wp_roles->roles)) {
			return $user_roles;
		}

		foreach ($wp_roles->roles as $slug => $role) {
			$user_roles[$slug] = $role['name'];
		}

		return $user_roles;
	}

}

if (!function_exists('bya_format_woo_order_status')) {

	/**
	 * Get woocommerce order status
	 * 
	 * @return array
	 * */
	function bya_format_woo_order_status( $order_statuses) {
		if (!bya_check_is_array($order_statuses)) {
			return;
		}

		$woo_order_statuses = array();

		foreach ($order_statuses as $order_status) {
			$woo_order_statuses[] = 'wc-' . $order_status;
		}

		return $woo_order_statuses;
	}

}

if (!function_exists('bya_allow_buy_again')) {

	/**
	 * Get buy again status
	 * 
	 * @return bool
	 * */
	function bya_allow_buy_again() {
		$enable_buy_again = get_option('bya_general_enable_buy_again', 'no');

		if ('yes' !== $enable_buy_again) {
			return false;
		}

		return true;
	}

}

if (!function_exists('bya_user_restriction')) {

	/**
	 * Get buy again user restriction status
	 * 
	 * @return bool
	 * */
	function bya_user_restriction( $user_id) {
		if (empty($user_id)) {
			return false;
		}

		$user = new WP_User($user_id);
		$user_role = '';

		if (!empty($user->roles) && bya_check_is_array($user->roles)) {
			foreach ($user->roles as $role) {
				$user_role = $role;
			}
		}

		$user_option = get_option('bya_advanced_allow_users', '1');
		$bool = true;

		if ('2' == $user_option) {
			$include_user = get_option('bya_advanced_include_user', array());
			$bool = ( in_array($user_id, $include_user) ) ? true : false;
		} elseif ('3' == $user_option) {
			$exclude_user = get_option('bya_advanced_exclude_user', array());
			$bool = ( in_array($user_id, $exclude_user) ) ? false : true;
		} elseif ('4' == $user_option) {
			$include_user_role = get_option('bya_include_user_role', array());
			$bool = ( in_array($user_role, $include_user_role) ) ? true : false;
		} elseif ('5' == $user_option) {
			$exclude_user_role = get_option('bya_exclude_user_role', array());
			$bool = ( in_array($user_role, $exclude_user_role) ) ? false : true;
		}

		return $bool;
	}

}

if (!function_exists('bya_product_restriction')) {

	/**
	 * Get buy again product restriction status
	 * 
	 * @return bool
	 * */
	function bya_product_restriction( $product_id) {

		if (empty($product_id)) {
			return false;
		}

		$product_option = get_option('bya_advanced_allow_products', '1');

		if ('2' === $product_option) {
			$include_products = get_option('bya_advanced_include_product', array());

			if (in_array($product_id, $include_products)) {
				return true;
			}

			return false;
		} elseif ('3' === $product_option) {
			$exclude_products = get_option('bya_advanced_exclude_product', array());

			if (!in_array($product_id, $exclude_products)) {
				return true;
			}

			return false;
		} elseif ('4' === $product_option) {
			$include_categories = get_option('bya_advanced_include_category', array());
			$product_obj = wc_get_product($product_id);
			$parent_id = $product_obj->get_parent_id();
			$product_id = !empty($parent_id) ? $parent_id : $product_id;
			$terms = get_the_terms($product_id, 'product_cat');

			if (bya_check_is_array($terms)) {
				foreach ($terms as $term) {
					if (in_array($term->term_id, $include_categories)) {
						return true;
					}
				}
			}
			return false;
		} elseif ('5' === $product_option) {
			$exclude_categories = get_option('bya_advanced_exclude_category', array());
			$product_obj = wc_get_product($product_id);
			$parent_id = $product_obj->get_parent_id();
			$product_id = !empty($parent_id) ? $parent_id : $product_id;
			$terms = get_the_terms($product_id, 'product_cat');

			if (bya_check_is_array($terms)) {
				foreach ($terms as $term) {
					if (in_array($term->term_id, $exclude_categories)) {
						return false;
					}
				}
			}

			return true;
		}

		return true;
	}

}

if (!function_exists('bya_customize_array_position')) {

	/**
	 * Get customize position of my-account menu
	 * 
	 * @return array
	 * */
	function bya_customize_array_position( $array, $key, $new_value) {
		$keys = array_keys($array);
		$index = array_search($key, $keys);
		$pos = false === $index ? count($array) : $index + 1;

		$new_value = is_array($new_value) ? $new_value : array($new_value);

		return array_merge(array_slice($array, 0, $pos), $new_value, array_slice($array, $pos));
	}

}

if (!function_exists('bya_get_product_ids_from_user_orders')) {

	/**
	 * Get product id's from user orders
	 * 
	 * @return array
	 * */
	function bya_get_product_ids_from_user_orders( $user_id) {

		if (0 == $user_id) {
			return;
		}

		$order_statuses = bya_format_woo_order_status(get_option('bya_general_order_status_to_show', array('processing', 'completed')));

		$customer_orders = get_posts(array(
			'numberposts' => -1,
			'meta_key' => '_customer_user',
			'meta_value' => $user_id,
			'post_type' => wc_get_order_types(),
			'post_status' => $order_statuses,
		));

		if (!$customer_orders) {
			return;
		}

		$product_ids = array();

		foreach ($customer_orders as $customer_order) {
			$order = wc_get_order($customer_order->ID);
			$items = $order->get_items();

			foreach ($items as $item_id => $item) {
				$product_id = $item->get_product_id();
				$variation_id = $item->get_variation_id();

				if (!empty($variation_id) && !bya_product_restriction($variation_id)) {
					continue;
				}

				if (empty($variation_id) && !bya_product_restriction($product_id)) {
					continue;
				}

				$product_obj = wc_get_product($product_id);

				if (!is_object($product_obj)) {
					continue;
				}

				$product_args = array(
					ucfirst($product_obj->get_title()),
					'order_id' => $customer_order->ID,
					'product_id' => $product_id,
					'variation_id' => !empty($variation_id) ? $variation_id : '',
					'item_id' => $item_id,
					'item' => $item,
					'order_count' => 1,
					'qty_count' => $item->get_quantity()
				);

				$unique_key = empty($variation_id) ? $product_id : $variation_id;

				if (!isset($product_ids[$unique_key]['product_id']) ||
						( isset($product_ids[$unique_key]['product_id']) && $product_id != $product_ids[$unique_key]['product_id'] ) ||
						( isset($product_ids[$unique_key]['variation_id']) && $variation_id != $product_ids[$unique_key]['variation_id'] )
				) {
					$product_ids[$unique_key] = $product_args;
				} else {
					$product_ids[$unique_key]['order_count'] = $product_ids[$unique_key]['order_count'] + $product_args['order_count'];
					$product_ids[$unique_key]['qty_count'] = $product_ids[$unique_key]['qty_count'] + $product_args['qty_count'];
				}
			}
		}

		return bya_sort_product_ids($product_ids);
	}

}

if (!function_exists('bya_add_to_cart_ajax_enable')) {

	/**
	 * Get add to cart ajax enable
	 * 
	 * @return string
	 * */
	function bya_add_to_cart_ajax_enable() {

		return get_option('woocommerce_enable_ajax_add_to_cart', 'yes');
	}

}

if (!function_exists('bya_get_product_url')) {

	/**
	 * Get product URL
	 * 
	 * @return bool
	 * */
	function bya_get_product_url( $product_id) {
		if (empty($product_id) || '0' == $product_id) {
			return;
		}

		return get_permalink($product_id);
	}

}

if (!function_exists('bya_get_buy_again_product_per_page_count')) {

	/**
	 * Get Buy Again Product Per Page Column Count
	 *
	 * @return number
	 */
	function bya_get_buy_again_product_per_page_count() {

		return get_option('bya_localization_myaccount_per_page_product_count', 5);
	}

}

if (!function_exists('bya_get_buy_again_product_table_heading')) {

	/**
	 * Get Buy Again Product Per table heading
	 *
	 * @return array
	 */
	function bya_get_buy_again_product_table_heading( $only_option = false) {
		$_columns = array();
		$_columns_display = array('show_image' => get_option('bya_localization_allow_product_image_col', 'yes'),
			'show_name' => get_option('bya_localization_allow_product_name_col', 'yes'),
			'show_description' => get_option('bya_localization_buy_again_table_product_desc', '2'),
			'show_order_count' => get_option('bya_localization_allow_order_count_col', 'no'),
			'show_price' => get_option('bya_localization_allow_product_price_col', 'yes'),
			'show_quantity' => get_option('bya_localization_allow_product_quantity_col', 'yes'),
			'show_action' => get_option('bya_localization_allow_action_col', 'yes')
		);

		if ($only_option) {
			return $_columns_display;
		}

		if ('yes' == $_columns_display['show_image']) {
			$_columns['image_label'] = get_option('bya_localization_product_image_label', esc_html__('Product Image', 'buy-again-for-woocommerce'));
		}

		if ('yes' == $_columns_display['show_name']) {
			$_columns['name_label'] = get_option('bya_localization_product_name_label', esc_html__('Product Name', 'buy-again-for-woocommerce'));
		}

		if ('yes' == $_columns_display['show_order_count']) {
			$_columns['order_count_label'] = get_option('bya_localization_order_count_label', esc_html__('Purchased quantity & order count', 'buy-again-for-woocommerce'));
		}

		if ('yes' == $_columns_display['show_price']) {
			$_columns['price_label'] = get_option('bya_localization_product_price_label', esc_html__('Product Price', 'buy-again-for-woocommerce'));
		}

		if ('yes' == $_columns_display['show_quantity']) {
			$_columns['quantity_label'] = get_option('bya_localization_product_quantity_label', esc_html__('Product Quantity', 'buy-again-for-woocommerce'));
		}

		if ('yes' == $_columns_display['show_action']) {
			$_columns['action_label'] = get_option('bya_localization_action_label', esc_html__('Action', 'buy-again-for-woocommerce'));
		}

		return $_columns;
	}

}

if (!function_exists('bya_add_to_cart')) {

	/**
	 * Get Buy Again Product Per table heading
	 *
	 * @return array
	 */
	function bya_add_to_cart( $product_id, $quantity, $variation_id = 0, $variation_array = array(), $cart_item_data = array()) {
		$cart_item_data['buy_again_product'] = array('bya_product');

		WC()->cart->add_to_cart($product_id, $quantity, $variation_id, $variation_array, $cart_item_data);
	}

}

if (!function_exists('bya_get_product_title')) {

	/**
	 * Get product title 
	 *
	 * @return string
	 */
	function bya_get_product_title( $product_id) {

		$product = wc_get_product($product_id);

		if (is_object($product)) {
			return $product->get_title();
		} else {
			return esc_html('Product not found', 'buy-again-for-woocommerce');
		}
	}

}

if (!function_exists('bya_get_purchase_history_url')) {

	/**
	 * Get Buy again Product Purchase history url
	 *
	 * @return string
	 */
	function bya_get_purchase_history_url() {
		return add_query_arg(array('post_type' => 'buy_again_list'), admin_url('edit.php'));
	}

}

if (!function_exists('bya_get_product_details_url')) {

	/**
	 * Get Buy again Product Purchase history url
	 *
	 * @return string
	 */
	function bya_get_product_details_url( $post_id, $user_id) {
		return add_query_arg(array('page' => 'bya_product_details', 'post' => $post_id, 'user_id' => $user_id), admin_url('admin.php'));
	}

}

if (!function_exists('bya_get_my_account_end_point_url')) {

	/**
	 * Get My account end point
	 *
	 * @return string
	 */
	function bya_get_my_account_end_point_url() {
		global $wp;

		if (!is_object($wp)) {
			return '';
		}

		return ( bya_check_is_array($wp->query_vars) ) ? bya_array_key_last($wp->query_vars) : '';
	}

}

if (!function_exists('bya_array_key_last')) {

	/**
	 * Get array key last
	 *
	 * @return string
	 */
	function bya_array_key_last( $array) {
		// 100000 iters: ~0.068 secs
		return key(array_slice($array, -1));
	}

}

if (!function_exists('bya_render_product_image')) {

	/**
	 * Get Product image
	 *
	 * @return string
	 */
	function bya_render_product_image( $product, $echo = true) {

		$allowed_html = array('a' => array(
				'href' => array(),
			),
			'img' => array(
				'class' => array(),
				'src' => array(),
				'alt' => array(),
				'srcset' => array(),
				'sizes' => array(),
				'width' => array(),
				'height' => array(),
				'data' => array()
			),
		);

		if ($echo) {
			echo wp_kses($product->get_image(array(50, 50)), $allowed_html);
		}

		return $product->get_image();
	}

}

if (!function_exists('bya_get_hidden_order_itemmeta')) {

	/**
	 * Get hidden order item meta
	 *
	 * @return Array
	 */
	function bya_get_hidden_order_itemmeta() {
		return apply_filters('bya_hidden_order_itemmeta', array(
			'_qty',
			'_tax_class',
			'_product_id',
			'_variation_id',
			'_line_subtotal',
			'_line_subtotal_tax',
			'_line_total',
			'_line_tax',
			'method_id',
			'cost',
			'_reduced_stock',
			'_buy_again_product',
			'_qc_buy_now_product'
		));
	}

}

if (!function_exists('bya_prepare_cart_item_data')) {

	/**
	 * Prepare cart item data for buy again
	 *
	 * @return Array
	 */
	function bya_prepare_cart_item_data( $order_id, $cart_item_data, $product_id, $variation_id) {
		if (empty($order_id)) {
			return $cart_item_data;
		}

		$order_obj = wc_get_order($order_id);

		if (!is_object($order_obj)) {
			return $cart_item_data;
		}

		$items = $order_obj->get_items();

		if (!bya_check_is_array($items)) {
			return $cart_item_data;
		}

		foreach ($items as $item_id => $item) {
			$bya_product_id = $item->get_product_id();
			$bya_variation_id = $item->get_variation_id();

			if ($bya_product_id != $product_id) {
				continue;
			}

			$hidden_order_itemmeta = bya_get_hidden_order_itemmeta();
			$meta_data = $item->get_formatted_meta_data('');

			if (!bya_check_is_array($meta_data)) {
				continue;
			}

			foreach ($meta_data as $meta_id => $meta) {
				if (in_array($meta->key, $hidden_order_itemmeta, true)) {
					continue;
				}

				$cart_item_data[$meta->key] = array($meta->display_key => $meta->display_value);
			}
		}

		return $cart_item_data;
	}

}

if (!function_exists('bya_prepare_cart_item_attr')) {

	/**
	 * Prepare cart item data for buy again
	 *
	 * @return Array
	 */
	function bya_prepare_cart_item_attr( $order_id, $cart_item_attr, $product_id, $variation_id) {
		if (empty($order_id)) {
			return $cart_item_attr;
		}

		$order_obj = wc_get_order($order_id);

		if (!is_object($order_obj)) {
			return $cart_item_attr;
		}

		$items = $order_obj->get_items();

		if (!bya_check_is_array($items)) {
			return $cart_item_attr;
		}

		foreach ($items as $item_id => $item) {
			$bya_product_id = $item->get_product_id();
			$bya_variation_id = $item->get_variation_id();

			if ($bya_product_id != $product_id) {
				continue;
			}

			$hidden_order_itemmeta = bya_get_hidden_order_itemmeta();
			$meta_data = $item->get_formatted_meta_data('');

			if (!bya_check_is_array($meta_data)) {
				continue;
			}

			foreach ($meta_data as $meta_id => $meta) {
				if (in_array($meta->key, $hidden_order_itemmeta, true)) {
					continue;
				}

				$cart_item_attr['attribute_' . $meta->key] = $meta->value;
			}
		}

		return $cart_item_attr;
	}

}

if (!function_exists('bya_get_display_custom_metas')) {

	/**
	 * Prepare cart item data for buy again
	 *
	 * @return Array
	 */
	function bya_get_display_custom_metas() {
		$display_metas = apply_filters('bya_display_custom_item_meta', array());

		return $display_metas;
	}

}

if (!function_exists('bya_sort_product_ids')) {

	/**
	 * Prepare cart item data for buy again
	 *
	 * @return Array
	 */
	function bya_sort_product_ids( $product_ids) {
		if (!bya_check_is_array($product_ids)) {
			return $product_ids;
		}

		$order_by = isset($_REQUEST['orderby']) ? wc_clean(wp_unslash($_REQUEST['orderby'])) : '';
		$_order = isset($_REQUEST['order']) ? wc_clean(wp_unslash($_REQUEST['order'])) : '';

		if ('recent' == $order_by) {
			return $product_ids;
		} elseif ('title' == $order_by) {
			if ('desc' == $_order) {
				arsort($product_ids);
			} else {
				asort($product_ids);
			}
		} else {
			if ('2' == get_option('bya_advanced_buy_again_table_sort', '1')) {
				asort($product_ids);
			}
		}

		return $product_ids;
	}

}

if (!function_exists('bya_get_buy_again_product_sort_options')) {

	/**
	 * Prepare cart item data for buy again
	 *
	 * @return Array
	 */
	function bya_get_buy_again_product_sort_options() {
		return array(
			'1' => esc_html__('Default Sorting', 'buy-again-for-woocommerce'),
			'2' => esc_html__('Sort by name: ascending', 'buy-again-for-woocommerce'),
			'3' => esc_html__('Sort by name: descending', 'buy-again-for-woocommerce'),
		);
	}

}
