<?php

/**
 * Buy Again for WooCommerce Main Class
 */
if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly.
}

if (!class_exists('FP_Buy_Again')) {

	/**
	 * Main FP_Buy_Again Class.
	 * */
	final class FP_Buy_Again {

		/**
		 * Version.
		 * */
		private $version = '2.7';

		/**
		 * The single instance of the class.
		 * */
		protected static $_instance = null;

		/**
		 * Load FP_Buy_Again Class in Single Instance.
		 */
		public static function instance() {
			if (is_null(self::$_instance)) {
				self::$_instance = new self();
			}

			return self::$_instance;
		}

		/* Cloning has been forbidden */

		public function __clone() {
			_doing_it_wrong(__FUNCTION__, 'You are not allowed to perform this action!!!', '1.0');
		}

		/**
		 * Unserialize the class data has been forbidden.
		 * */
		public function __wakeup() {
			_doing_it_wrong(__FUNCTION__, 'You are not allowed to perform this action!!!', '1.0');
		}

		/**
		 * Constructor.
		 * */
		public function __construct() {

			/* Include once will help to avoid fatal error by load the files when you call init hook */
			include_once( ABSPATH . 'wp-admin/includes/plugin.php' );

			$this->header_already_sent_problem();
			$this->define_constants();
			$this->include_files();
			$this->init_hooks();
		}

		/**
		 * Function to prevent header error that says you have already sent the header.
		 */
		private function header_already_sent_problem() {
			ob_start();
		}

		/**
		 * Load plugin the translate files.
		 * */
		private function load_plugin_textdomain() {
			if (function_exists('determine_locale')) {
				$locale = determine_locale();
			} else {
				// @todo Remove when start supporting WP 5.0 or later.
				$locale = is_admin() ? get_user_locale() : get_locale();
			}

			$locale = apply_filters('plugin_locale', $locale, 'buy-again-for-woocommerce');

			unload_textdomain('buy-again-for-woocommerce');
			load_textdomain('buy-again-for-woocommerce', WP_LANG_DIR . '/buy-again-for-woocommerce/buy-again-for-woocommerce-' . $locale . '.mo');
			load_plugin_textdomain('buy-again-for-woocommerce', false, dirname(plugin_basename(BYA_PLUGIN_FILE)) . '/languages');
		}

		/**
		 * Prepare the constants value array.
		 * */
		private function define_constants() {
			$protocol = 'http://';

			if (isset($_SERVER['HTTPS']) && ( 'on' == $_SERVER['HTTPS'] || 1 == $_SERVER['HTTPS'] ) || isset($_SERVER['HTTP_X_FORWARDED_PROTO']) && 'https' == $_SERVER['HTTP_X_FORWARDED_PROTO']) {
				$protocol = 'https://';
			}

			$constant_array = array(
				'BYA_VERSION' => $this->version,
				'BYA_FOLDER_NAME' => 'buy-again-for-woocommerce',
				'BYA_ABSPATH' => dirname(BYA_PLUGIN_FILE) . '/',
				'BYA_ADMIN_URL' => admin_url('admin.php'),
				'BYA_ADMIN_AJAX_URL' => admin_url('admin-ajax.php'),
				'BYA_PLUGIN_SLUG' => plugin_basename(BYA_PLUGIN_FILE),
				'BYA_PLUGIN_PATH' => untrailingslashit(plugin_dir_path(BYA_PLUGIN_FILE)),
				'BYA_PLUGIN_URL' => untrailingslashit(plugins_url('/', BYA_PLUGIN_FILE)),
				'BYA_PROTOCOL' => $protocol,
			);

			$constant_array = apply_filters('bya_define_constants', $constant_array);

			if (is_array($constant_array) && !empty($constant_array)) {
				foreach ($constant_array as $name => $value) {
					$this->define_constant($name, $value);
				}
			}
		}

		/**
		 * Define the Constants value.
		 * */
		private function define_constant( $name, $value) {
			if (!defined($name)) {
				define($name, $value);
			}
		}

		/**
		 * Include required files.
		 * */
		private function include_files() {
			// Function.
			include_once( BYA_ABSPATH . 'inc/bya-common-functions.php' );
			// Abstract classes.
			include_once( BYA_ABSPATH . 'inc/abstracts/class-bya-post.php' );
			// Privacy Policy.
			include_once( BYA_ABSPATH . 'inc/privacy/class-bya-privacy.php' );
			// Custom Post Types
			include_once( BYA_ABSPATH . 'inc/class-bya-register-post-types.php' );
			include_once( BYA_ABSPATH . 'inc/class-bya-register-post-status.php' );
			include_once( BYA_ABSPATH . 'inc/class-bya-install.php' );
			include_once( BYA_ABSPATH . 'inc/class-bya-date-time.php' );
			// Entity.
			include_once( BYA_ABSPATH . 'inc/entity/class-bya-buy-again-log.php' );
			//Query Function
			include_once( BYA_ABSPATH . 'inc/class-bya-query.php' );
			//order handler
			include_once( BYA_ABSPATH . 'inc/class-bya-order-handler.php' );

			if (is_admin()) {
				$this->include_admin_files();
			}

			if (!is_admin() || defined('DOING_AJAX')) {
				$this->include_frontend_files();
			}
		}

		/**
		 * Include admin files.
		 * */
		private function include_admin_files() {
			include_once( BYA_ABSPATH . 'inc/admin/class-bya-admin-assets.php' );
			include_once( BYA_ABSPATH . 'inc/admin/class-bya-admin-ajax.php' );
			include_once( BYA_ABSPATH . 'inc/admin/menu/class-bya-menu-management.php' );
			include_once( BYA_ABSPATH . 'inc/admin/menu/class-bya-buy-again-list-table.php' );
		}

		/**
		 * Include frontend files.
		 * */
		private function include_frontend_files() {
			include_once( BYA_ABSPATH . 'inc/frontend/class-bya-product-notice-handler.php' );
			include_once( BYA_ABSPATH . 'inc/frontend/class-bya-order-page-item-handler.php' );
			include_once( BYA_ABSPATH . 'inc/frontend/class-bya-frontend-assets.php' );
			include_once( BYA_ABSPATH . 'inc/frontend/class-bya-my-account-handler.php' );
			include_once( BYA_ABSPATH . 'inc/frontend/class-bya-cart-handler.php' );
			include_once( BYA_ABSPATH . 'inc/frontend/class-bya-shortcodes.php' );
		}

		/**
		 * Define the hooks.
		 * */
		private function init_hooks() {

			// Init the plugin.
			add_action('init', array($this, 'init'));

			add_action('plugins_loaded', array($this, 'plugins_loaded'));
			// Register the plugin.
			register_activation_hook(BYA_PLUGIN_FILE, array('BYA_Install', 'install'));
		}

		/**
		 * Init.
		 * */
		public function init() {

			$this->load_plugin_textdomain();
		}

		/**
		 * Plugins Loaded.
		 * */
		public function plugins_loaded() {
			do_action('bya_after_plugin_loaded');
		}

		/**
		 * Templates.
		 * */
		public function templates() {
			return BYA_PLUGIN_PATH . '/templates/';
		}

	}

}
