<?php

/**
 * Frontend Assets
 */
if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly.
}
if (!class_exists('BYA_Fronend_Assets')) {

	/**
	 * Class.
	 */
	class BYA_Fronend_Assets {

		/**
		 * Class Initialization.
		 */
		public static function init() {

			add_action('wp_enqueue_scripts', array(__CLASS__, 'external_js_files'));
			add_action('wp_enqueue_scripts', array(__CLASS__, 'external_css_files'));
		}

		/**
		 * Enqueue external JS files
		 */
		public static function external_js_files() {
			$current_url = '';
			
			if (isset($_SERVER['HTTP_HOST']) && isset($_SERVER['REQUEST_URI'])) {
				$current_url = BYA_PROTOCOL . wc_clean(wp_unslash($_SERVER['HTTP_HOST'])) . wc_clean(wp_unslash($_SERVER['REQUEST_URI']));
			}
			
			// Frontend
			wp_enqueue_script('bya-frontend', BYA_PLUGIN_URL . '/assets/js/frontend.js', array('wc-add-to-cart', 'jquery', 'jquery-blockui', 'jquery-ui-core', 'jquery-ui-dialog'), BYA_VERSION);
			wp_localize_script('bya-frontend', 'bya_frontend_params', array(
				'add_to_cart_nonce' => wp_create_nonce('bya-add-to-cart-nonce'),
				'redirect_add_to_cart' => get_option('woocommerce_cart_redirect_after_add', 'no'),
				'ajax_add_to_cart' => get_option('woocommerce_enable_ajax_add_to_cart', 'yes'),
				'buy_again_nonce' => wp_create_nonce('bya-buy-again-nonce'),
				'pagination_nonce' => wp_create_nonce('bya-product-pagination-nonce'),
				'search_nonce' => wp_create_nonce('bya-product-search-nonce'),
				'ajaxurl' => BYA_ADMIN_AJAX_URL,
				'current_page_url' => get_permalink(),
				'bya_get_my_account_end_point_url' => bya_get_my_account_end_point_url(),
				'cart_url' => wc_get_cart_url(),
				'view_cart_label' => esc_html__('view cart', 'buy-again-for-woocommerce'),
				'user_id' => get_current_user_id(),
				'orderby' => isset($_REQUEST['orderby']) ? wc_clean(wp_unslash($_REQUEST['orderby'])) : '',
				'order' => isset($_REQUEST['order']) ? wc_clean(wp_unslash($_REQUEST['order'])) : '',
				'current_url' => $current_url,
					)
			);
		}

		public static function external_css_files() {
			// Frontend
			wp_enqueue_style('bya-frontend-css', BYA_PLUGIN_URL . '/assets/css/frontend.css', array(), BYA_VERSION);
			// Add custom css
			self::add_inline_style();
		}

		/**
		 * Add Inline style
		 */
		public static function add_inline_style() {
			$contents = get_option('bya_advanced_custom_css', '');

			if ( '2' == get_option('bya_advanced_buy_again_table_product_img_disp', '1')) {
				$product_img_size = get_option('bya_product_img_size', array('width' => 75, 'height' => 50));
				$contents .= '.bya_product_table_container .bya_buy_again_product_table tbody td img.bya_product_img {
                    width:' . $product_img_size['width'] . 'px ;
                    height: ' . $product_img_size['height'] . 'px ;
                    max-width: none;
                    }';
			}

			if (!$contents) {
				return;
			}

			//Add custom css as inline style.
			wp_add_inline_style('bya-frontend-css', $contents);
		}

	}

	BYA_Fronend_Assets::init();
}
