<?php
/**
 * This template displays MyAccount Buy Again Products
 *
 * This template can be overridden by copying it to yourtheme/buy-again-for-woocommerce/myaccount-buy-again-table.php
 *
 * To maintain compatibility, buy again will update the template files and you have to copy the updated files to your theme
 */

if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly.
}
?>
<div class="bya_myaccount_buy_again_wrapper">
	<?php
	$_columns = bya_get_buy_again_product_table_heading();
	$_columns_display = bya_get_buy_again_product_table_heading(true);
	?>
	<tbody>
		<?php
		foreach ($product_ids as $product_args) {
			if (!bya_check_is_array($product_args)) {
				continue;
			}

			extract($product_args);

			$product_obj = wc_get_product($product_id);

			if ($variation_id) {
				$product_obj = wc_get_product($variation_id);
			}

			if (!is_object($product_obj)) {
				continue;
			}

			$quantity_id = ( $variation_id ) ? 'bsf_qty_' . $variation_id : 'bsf_qty_' . $product_id;
			$quantity_max = $product_obj->backorders_allowed() ? '' : $product_obj->get_stock_quantity();
			?>
			<tr>    
				<?php if ('yes' == $_columns_display['show_image']) { ?>
					<td data-title="<?php echo esc_attr($_columns['image_label']); ?>">
						<?php
						$feature_image = wp_get_attachment_image_src(get_post_thumbnail_id(esc_attr($product_id)), 'single-post-thumbnail');
						if ($product_obj->get_image_id() && bya_check_is_array($feature_image)) {
							?>
							<img class="bya_product_img" src="<?php echo esc_url($feature_image[0]); ?>" data-id="<?php echo esc_attr($product_id); ?>">
							<?php
						} else {
							echo sprintf('<img src="%s" alt="%s" class="bya_product_img wp-post-image" />', esc_url(wc_placeholder_img_src('woocommerce_single')), esc_html__('Awaiting product image', 'woocommerce'));
						}
						?>
					</td>
					<?php
				}
				if ('yes' == $_columns_display['show_name']) {
					?>
					<td data-title="<?php echo esc_attr($_columns['name_label']); ?>">
						<?php
						$product_title = apply_filters('bya_table_item_name', $product_obj->get_permalink($item), array('product_id' => $product_id, 'variation_id' => $variation_id), '');
						echo sprintf('<a class="bya_link bya_product_title" href="%s">%s</a>', esc_url($product_title), esc_attr($item->get_name()));
						wc_display_item_meta($item);
						
						if ( '1' == $_columns_display['show_description']) { 
							$product_descripiton = apply_filters('bya_table_item_description', $product_obj->get_description());
							?>
						
						<p class="bya_product_description">
							<?php echo wp_kses_post(wc_format_content($product_descripiton)); ?>
						</p>
						<?php } ?>
					</td>
					<?php
				}

				if ('yes' == $_columns_display['show_order_count']) {
					?>
					<td data-title="<?php echo esc_attr($_columns['order_count_label']); ?>">
						<?php 
						$shortcode_array = array('[qty_count]', '[order_count]');
						$replace_array = array($product_args['qty_count'], $product_args['order_count']);
						$message_label = get_option('bya_localization_order_count_val', '[qty_count] quantity of [order_count] order(s)');
						$order_count = str_replace( $shortcode_array , $replace_array , $message_label ) ;
						echo wp_kses_post($order_count); 
						?>
					</td>
					<?php
				}

				if ('yes' == $_columns_display['show_price']) {
					?>
					<td data-title="<?php echo esc_attr($_columns['price_label']); ?>">
						<?php
						if ('excl' === get_option('woocommerce_tax_display_cart')) {
							$product_price = wc_get_price_excluding_tax($product_obj);
						} else {
							$product_price = wc_get_price_including_tax($product_obj);
						}

						bya_price($product_price);
						?>
					</td>
					<?php
				}

				if ('yes' == $_columns_display['show_quantity']) {
					?>
					 
					<td data-title="<?php echo esc_attr($_columns['quantity_label']); ?>">
						<?php
						$args = array(
							'qty_allow' => true,
							'input_id' => $quantity_id,
							'input_name' => 'quantity',
							'input_value' => '1',
							'classes' => apply_filters('woocommerce_quantity_input_classes', array('bya_qty_field', 'input-text', 'qty', 'text'), $product_obj),
							'max_value' => apply_filters('woocommerce_quantity_input_max', $quantity_max, $product_obj),
							'min_value' => apply_filters('woocommerce_quantity_input_min', 1, $product_obj),
							'step' => apply_filters('woocommerce_quantity_input_step', 1, $product_obj),
							'pattern' => apply_filters('woocommerce_quantity_input_pattern', has_filter('woocommerce_stock_amount', 'intval') ? '[0-9]*' : ''),
							'inputmode' => apply_filters('woocommerce_quantity_input_inputmode', has_filter('woocommerce_stock_amount', 'intval') ? 'numeric' : ''),
							'product_name' => $product_obj ? $product_obj->get_title() : '',
							'placeholder' => apply_filters('woocommerce_quantity_input_placeholder', '', $product_obj),
							'product_id' => $product_id,
							'variation_id' => $variation_id,
						);

						$args = apply_filters('woocommerce_quantity_input_args', $args, $product_obj);

						bya_get_template('quantity-input.php', $args);
						?>
					</td>
					<?php
				}

				if ('yes' == $_columns_display['show_action']) {
					?>
					<td data-title="<?php echo esc_attr($_columns['action_label']); ?>">
						<?php
						$args = array(
							'product_id' => $product_id,
							'variation_id' => $variation_id,
							'price' => $product_price,
							'quantity_id' => $quantity_id,
							'add_to_cart_class' => 'bsf_add_to_cart_' . $product_id,
							'add_to_cart_ajax_enable' => bya_add_to_cart_ajax_enable(),
							'cartlink' => '?add-to-cart=' . $product_id,
							'qty_allow' => false,
							'bya_get_my_account_end_point_url' => $bya_get_my_account_end_point_url,
							'bya_order_id' => $order_id,
						);

						bya_get_template('display-input-fields.php', $args);
						?>
					</td>
				<?php } ?>
			</tr>
		<?php } ?>
	</tbody>
